/// <reference path="fourslash.ts" />

////var /**/x = /aa/;
 
goTo.marker();
verify.quickInfoIs("var x: RegExp");
